@@ -34,6 +34,8 @@
 #endif
 
 #include <sstream>
+#include <algorithm>
+#include <iterator>
 
 #include <rcsc/param/server_param.h>
 #include <rcsc/param/player_param.h>
@@ -216,14 +218,12 @@ CoachAgent::doInit( const int argc,
     ParamMap coach_param_map( "Coach options" );
     M_config.createParamMap( coach_param_map );
 
-    ParamMap all_params;
-    all_params.add( system_param_map ).add( coach_param_map );
-
 
     CmdLineParser cmd_parser( argc, argv );
 
-    // analyze command line
-    if ( ! cmd_parser.parse( all_params ) )
+    // analyze command line for system options
+    cmd_parser.parse( system_param_map );
+    if ( help )
     {
         system_param_map.printHelp( std::cout );
         coach_param_map.printHelp( std::cout );
@@ -236,10 +236,19 @@ CoachAgent::doInit( const int argc,
     {
         ConfFileParser conf_parser( coach_config_file.c_str() );
         conf_parser.parse( coach_param_map );
-        // analyze command line again to overwiite the config file setting
-        cmd_parser.parse( all_params );
     }
 
+    // analyze command line for coach options
+    cmd_parser.parse( coach_param_map );
+
+    if ( ! cmd_parser.invalidOptions().empty() )
+    {
+        std::cerr << "coach: ***WARNING*** detected invalid options: ";
+        std::copy( cmd_parser.invalidOptions().begin(),
+                   cmd_parser.invalidOptions().end(),
+                   std::ostream_iterator< std::string >( std::cerr, " " ) );
+        std::cerr << std::endl;
+    }
     return true;
 }
 
