@@ -48,10 +48,12 @@ namespace rcsc {
 //! the implementation of file stream buffer
 struct gzfilebuf_impl {
 
+    //! file open mode flag
     std::ios_base::openmode open_mode_;
 
 #ifdef HAVE_LIBZ
-    gzFile file_; //!< gzip file
+    //! gzip file
+    gzFile file_;
 #endif
 
     //! constructor
@@ -67,8 +69,7 @@ struct gzfilebuf_impl {
 
 /*-------------------------------------------------------------------*/
 /*!
-  Default constructor creates an internal file buffer using boost::scoped_ptr.
-  This buffer is deleted automatically.
+
 */
 gzfilebuf::gzfilebuf()
     : M_impl( new gzfilebuf_impl )
@@ -81,8 +82,7 @@ gzfilebuf::gzfilebuf()
 
 /*-------------------------------------------------------------------*/
 /*!
-  Opend file is closed.
-  Dynamically allocated internal buffer is deleted.
+
 */
 gzfilebuf::~gzfilebuf()
 {
@@ -101,7 +101,7 @@ gzfilebuf::~gzfilebuf()
 
 /*-------------------------------------------------------------------*/
 /*!
-  \return returns true if file is opend, else false.
+
 */
 bool
 gzfilebuf::is_open()
@@ -119,16 +119,7 @@ gzfilebuf::is_open()
 
 /*-------------------------------------------------------------------*/
 /*!
-  If file is already opened, this method has no effect.
-  If file is opened successfully, buffer is also allocated.
-  This buffer is deleted when gzfilebuf is deleted.
-  \param path file path to open
-  \param mode specifies mode of I/O. Only std::ios_base::in or
-  std::ios_base::out can be used.
-  \param level compression level(0-9, -1 means default level)
-  \param strategy compression strategy.
-  Z_DEFAULT_COMPRESSION, Z_FILTERD, Z_HUFFMAN_ONLY or Z_RLE.
-  For more details, see deflateInit2 in zlib.h.
+
 */
 gzfilebuf *
 gzfilebuf::open( const char * path,
@@ -201,9 +192,7 @@ gzfilebuf::open( const char * path,
 
 /*-------------------------------------------------------------------*/
 /*!
-  closes the file if opened.
-  \return pointer to this object if close operation is failed
-  \retval NULL file is closed successfully.
+
 */
 gzfilebuf *
 gzfilebuf::close() throw()
@@ -238,8 +227,7 @@ gzfilebuf::close() throw()
 
 /*-------------------------------------------------------------------*/
 /*!
-  flush current internal buffer.
-  This method is called from close(), sync() and overflow().
+
 */
 bool
 gzfilebuf::flushBuf()
@@ -271,12 +259,7 @@ gzfilebuf::flushBuf()
 
 /*-------------------------------------------------------------------*/
 /*!
-  create a string to determine the type of zlib file operation.
-  For more details, see gzopen in zlib.h
-  \param mode determins I/O mode. Only std::ios_base::in or
-  std::ios_base::out can be used.
-  \param level compression level.
-  \param strategy compression strategy.
+
 */
 std::string
 gzfilebuf::makeModeString( std::ios_base::openmode mode,
@@ -318,7 +301,7 @@ gzfilebuf::makeModeString( std::ios_base::openmode mode,
               && level <= BEST_COMPRESSION )
     {
         char lvstr[4];
-        std::sprintf( lvstr, "%d", level );
+        std::snprintf( lvstr, 4, "%d", level );
         mode_str += lvstr;
     }
     else
@@ -351,8 +334,7 @@ gzfilebuf::makeModeString( std::ios_base::openmode mode,
 
 /*-------------------------------------------------------------------*/
 /*!
-  Internal buffer is deleted.
-  The pointers used in super class are reset.
+
 */
 void
 gzfilebuf::destroyInternalBuffer() throw()
@@ -370,11 +352,10 @@ gzfilebuf::destroyInternalBuffer() throw()
 
 /*-------------------------------------------------------------------*/
 /*!
-  Put character at current put position.
-  \param c this char is put to file.
+
 */
-gzfilebuf::int_type
-gzfilebuf::overflow( gzfilebuf::int_type c )
+std::streambuf::int_type
+gzfilebuf::overflow( std::streambuf::int_type c )
 {
     //std::cerr << "gzfilebuf::overflow" << std::endl;
     flushBuf();
@@ -389,7 +370,7 @@ gzfilebuf::overflow( gzfilebuf::int_type c )
 
 /*-------------------------------------------------------------------*/
 /*!
-  \param off offset to move. This is decompressed data size.
+
 */
 std::streampos
 gzfilebuf::seekoff( std::streamoff off,
@@ -562,7 +543,7 @@ gzfilebuf::uflow()
 /*!
 
 */
-gzfilebuf::int_type
+std::streambuf::int_type
 gzfilebuf::underflow()
 {
 #ifdef HAVE_LIBZ
@@ -683,8 +664,7 @@ gzifstream::gzifstream()
 
 /*-------------------------------------------------------------------*/
 /*!
-  construct stream
-  \param name file name.
+
 */
 gzifstream::gzifstream( const char * path )
     : std::istream( static_cast< std::streambuf* >( 0 ) )
@@ -696,14 +676,7 @@ gzifstream::gzifstream( const char * path )
 
 /*-------------------------------------------------------------------*/
 /*!
-  Stream will be in state good() if file opens successfully;
-  otherwise in state fail(). This differs from the behavior of
-  ifstream, which never sets the state to good() and therefore
-  won't allow you to reuse the stream for a second file unless
-  you manually clear() the state. The choice is a matter of
-  convenience.
-  \param name file name.
-  \param mode open mode flags (forced to contain ios::in).
+
 */
 void
 gzifstream::open( const char * path )
@@ -720,8 +693,7 @@ gzifstream::open( const char * path )
 
 /*-------------------------------------------------------------------*/
 /*!
-  close file.
-  stream will be in state fail() if close failed.
+
 */
 void
 gzifstream::close()
@@ -736,7 +708,7 @@ gzifstream::close()
 
 /*-------------------------------------------------------------------*/
 /*!
-  default constructor initializes stream buffer
+
 */
 gzofstream::gzofstream()
     : std::ostream( static_cast< std::streambuf * >( 0 ) )
@@ -747,37 +719,28 @@ gzofstream::gzofstream()
 
 /*-------------------------------------------------------------------*/
 /*!
-  initialize stream buffer and open file
-  \param name file name.
-  \param mode Open mode flags (forced to contain ios::out).
+
 */
-gzofstream::gzofstream( const char * name,
+gzofstream::gzofstream( const char * path,
                         int level,
                         int strategy )
     : std::ostream( static_cast< std::streambuf * >( 0 ) )
     , M_file_buf()
 {
     this->init( &M_file_buf );
-    this->open( name, level, strategy );
+    this->open( path, level, strategy );
 }
 
 /*-------------------------------------------------------------------*/
 /*!
-  open gzipped file.
-  Stream will be in state good() if file opens successfully;
-  otherwise in state fail().
-  This differs from the behavior of ofstream, which never sets
-  the state to good() and therefore won't allow you to reuse
-  the stream for a second file unless you manually clear() the state.
-  The choice is a matter of convenience.
-  \param name file name.
+
 */
 void
-gzofstream::open( const char * name,
+gzofstream::open( const char * path,
                   int level,
                   int strategy )
 {
-    if ( ! M_file_buf.open( name, std::ios_base::out, level, strategy ) )
+    if ( ! M_file_buf.open( path, std::ios_base::out, level, strategy ) )
     {
         this->setstate( std::ios_base::failbit );
     }
@@ -789,8 +752,7 @@ gzofstream::open( const char * name,
 
 /*-------------------------------------------------------------------*/
 /*!
-  close gzipped file.
-  if close failed, stream will be in state fail().
+
 */
 void
 gzofstream::close()
