@@ -36,6 +36,8 @@
 #include <cstdio>
 #include <cstring>
 #include <sstream>
+#include <algorithm>
+#include <iterator>
 
 #include <rcsc/math_util.h>
 #include <rcsc/game_mode.h>
@@ -467,8 +469,8 @@ PlayerAgent::seeTimeStamp() const
 
 */
 bool
-PlayerAgent::doInit(  const int argc,
-                      const char * const * argv )
+PlayerAgent::doInit( const int argc,
+                     const char * const * argv )
 {
     bool help = false;
     std::string player_config_file;
@@ -481,15 +483,12 @@ PlayerAgent::doInit(  const int argc,
     ParamMap player_param_map( "Player options" );
     M_config.createParamMap( player_param_map );
 
-    ParamMap all_params;
-    all_params.add( system_param_map ).add( player_param_map );
-
 
     CmdLineParser cmd_parser( argc, argv );
 
-    // analyze command line for all options.
-    if ( ! cmd_parser.parse( all_params )
-         || help )
+    // analyze command line for system options.
+    cmd_parser.parse( system_param_map );
+    if ( help )
     {
         system_param_map.printHelp( std::cout );
         player_param_map.printHelp( std::cout );
@@ -502,10 +501,19 @@ PlayerAgent::doInit(  const int argc,
     {
         ConfFileParser conf_parser( player_config_file.c_str() );
         conf_parser.parse( player_param_map );
-        // analyze command line again to overwiite the config file setting
-        cmd_parser.parse( all_params );
     }
 
+    // analyze command line for player options.
+    cmd_parser.parse( player_param_map );
+
+    if ( ! cmd_parser.invalidOptions().empty() )
+    {
+        std::cerr << "player: ***WARNING*** detected invalid options: ";
+        std::copy( cmd_parser.invalidOptions().begin(),
+                   cmd_parser.invalidOptions().end(),
+                   std::ostream_iterator< std::string >( std::cerr, " " ) );
+        std::cerr << std::endl;
+    }
 
     setDebugFlags();
 
