@@ -2,13 +2,13 @@
 
 /*!
   \file rcg.h
-  \brief Library Main Header File.
+  \brief RCG library Header File.
 */
 
 /*
  *Copyright:
 
- Copyright (C) 2004 Hidehisa Akiyama
+ Copyright (C) Hidehisa AKIYAMA
 
  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
@@ -29,8 +29,8 @@
 
 /////////////////////////////////////////////////////////////////////
 
-#ifndef RCTOOLS_RCSC_RCG_H
-#define RCTOOLS_RCSC_RCG_H
+#ifndef RCSC_RCG_H
+#define RCSC_RCG_H
 
 #include <rcsc/rcg/types.h>
 #include <rcsc/rcg/util.h>
