@@ -8,7 +8,7 @@
 /*
  *Copyright:
 
- Copyright (C) Hidehisa Akiyama
+ Copyright (C) Hidehisa AKIYAMA
 
  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
@@ -29,15 +29,21 @@
 
 /////////////////////////////////////////////////////////////////////
 
-#ifndef RCTOOLS_RCSC_RCG_FACTORY_H
-#define RCTOOLS_RCSC_RCG_FACTORY_H
+#ifndef RCSC_RCG_FACTORY_H
+#define RCSC_RCG_FACTORY_H
 
 #include <rcsc/rcg/parser.h>
 
 namespace rcsc {
 namespace rcg {
 
-//! returns the pointer to parser instance
+/*!
+  \brief make the suitable version parser instance depending on input
+  \param istrm reference to the imput stream.
+  \return rcg version number.
+
+  after checking, the pionted index of istreambuf becomes 4.
+*/
 ParserPtr
 make_parser( std::istream & istrm );
 
