@@ -8,7 +8,7 @@
 /*
  *Copyright:
 
- Copyright (C) Hidehisa Akiyama
+ Copyright (C) Hidehisa AKIYAMA
 
  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
@@ -46,41 +46,38 @@ namespace rcg {
 
 /*-------------------------------------------------------------------*/
 /*!
-  \param istrm reference to the imput stream (usually ifstream).
-  \param handler reference to the rcg data handler.
-  \retval true if successfuly parsed.
-  \retval false if incorrect format is detected.
+
 */
 bool
-ParserV2::parse( std::istream & istrm,
+ParserV2::parse( std::istream & is,
                  Handler & handler ) const
 {
     // streampos must be the first point!!!
-    istrm.seekg( 0 );
+    is.seekg( 0 );
 
-    if ( ! istrm.good() )
+    if ( ! is.good() )
     {
         return false;
     }
 
     // skip header
     char header[4];
-    istrm.read( header, 4 ); // read 'U', 'L', 'G', <version>
+    is.read( header, 4 ); // read 'U', 'L', 'G', <version>
 
     // register log version
     handler.handleLogVersion( REC_VERSION_2 );
 
     // main loop
-    while ( istrm.good() )
+    while ( is.good() )
     {
         // read data
-        if ( ! parseData( istrm, handler ) )
+        if ( ! parseData( is, handler ) )
         {
             return false;
         }
     }
 
-    if ( istrm.eof() )
+    if ( is.eof() )
     {
         return handler.handleEOF();
     }
@@ -90,25 +87,19 @@ ParserV2::parse( std::istream & istrm,
 
 /*-------------------------------------------------------------------*/
 /*!
-  This method is called in the loop of main parse method.
-  First, check the type of data mode.
-  Second, call each data item parsing method.
-  \param istrm reference to the imput stream (usually ifstream).
-  \param handler reference to the rcg data handler.
-  \retval true if successfuly parsed.
-  \retval false if incorrect format is detected.
+
 */
 bool
-ParserV2::parseData( std::istream & istrm,
+ParserV2::parseData( std::istream & is,
                      Handler & handler ) const
 {
     // chedk data mode.
     dispinfo_t info;
-    istrm.read( reinterpret_cast< char* >( &info.mode ), sizeof( short ) );
+    is.read( reinterpret_cast< char* >( &info.mode ), sizeof( short ) );
 
-    if ( ! istrm.good() )
+    if ( ! is.good() )
     {
-        if ( istrm.eof() )
+        if ( is.eof() )
         {
             return true;
         }
@@ -120,34 +111,35 @@ ParserV2::parseData( std::istream & istrm,
     case NO_INFO:
         return true;
     case SHOW_MODE:
-        istrm.read( reinterpret_cast< char* >( &info.body.show ),
-                    sizeof( showinfo_t ) );
-        if ( istrm.gcount() == sizeof( showinfo_t ) )
+        is.read( reinterpret_cast< char* >( &info.body.show ),
+                 sizeof( showinfo_t ) );
+        if ( is.gcount() == sizeof( showinfo_t ) )
         {
             return handler.handleShowInfo( info.body.show );
         }
         break;
     case MSG_MODE:
-        istrm.read( reinterpret_cast< char* >( &info.body.msg ),
-                    sizeof( msginfo_t ) );
-        if ( istrm.gcount() == sizeof( msginfo_t ) )
+        is.read( reinterpret_cast< char* >( &info.body.msg ),
+                 sizeof( msginfo_t ) );
+        if ( is.gcount() == sizeof( msginfo_t ) )
         {
             return handler.handleShowInfo( info.body.show );
         }
 
         break;
     case DRAW_MODE:
-        istrm.read( reinterpret_cast< char* >( &info.body.draw ),
-                    sizeof( drawinfo_t ) );
-        if ( istrm.gcount() == sizeof( drawinfo_t ) )
+        is.read( reinterpret_cast< char* >( &info.body.draw ),
+                 sizeof( drawinfo_t ) );
+        if ( is.gcount() == sizeof( drawinfo_t ) )
         {
             return true;
         }
         break;
     default:
         std::cerr << __FILE__ << ':' << __LINE__
-                  << "Unknown mode" << htons( info.mode )
+                  << " Unknown mode" << htons( info.mode )
                   << std::endl;;
+        break;
     }
 
     return false;
