@@ -8,7 +8,7 @@
 /*
  *Copyright:
 
- Copyright (C) Hidehisa Akiyama
+ Copyright (C) Hidehisa AKIYAMA
 
  This code is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
@@ -29,31 +29,55 @@
 
 /////////////////////////////////////////////////////////////////////
 
-#ifndef RCTOOLS_RCSC_RCG_PARSER_V2_H
-#define RCTOOLS_RCSC_RCG_PARSER_V2_H
+#ifndef RCSC_RCG_PARSER_V2_H
+#define RCSC_RCG_PARSER_V2_H
 
 #include <rcsc/rcg/parser.h>
 
 namespace rcsc {
 namespace rcg {
 
-//! rcg v2 parser class
+/*!
+  \class ParserV2
+  \brief rcg v2 parser
+ */
 class ParserV2
     : public Parser {
 public:
 
-    //! return version number
+    /*!
+      \brief get supported rcg version
+      \return version number
+     */
     int version() const
       {
           return REC_VERSION_2;
       }
 
-    //! operation method
-    bool parse( std::istream & istrm, Handler & handler ) const;
+    /*!
+      \brief parse input stream. hander will handle each data block.
+      \param is reference to the imput stream (usually ifstream).
+      \param handler reference to the rcg data handler.
+      \retval true if successfuly parsed.
+      \retval false if incorrect format is detected.
+    */
+    bool parse( std::istream & is,
+                Handler & handler ) const;
 
 private:
-    //! parse data block.
-    bool parseData( std::istream & istrm, Handler & handler ) const;
+    /*!
+      \brief parse data block.
+      \param is reference to the imput stream (usually ifstream).
+      \param handler reference to the rcg data handler.
+      \retval true if successfuly parsed.
+      \retval false if incorrect format is detected.
+
+      This method is called in the loop of main parse() method.
+      First, check the type of data mode.
+      Second, call matched handler method.
+    */
+    bool parseData( std::istream & is,
+                    Handler & handler ) const;
 };
 
 } // end of namespace
