@@ -34,6 +34,8 @@
 #endif
 
 #include <sstream>
+#include <algorithm>
+#include <iterator>
 
 #include <rcsc/random.h>
 #include <rcsc/param/server_param.h>
@@ -214,14 +216,12 @@ TrainerAgent::doInit( const int argc,
     ParamMap trainer_param_map( "Trainer options" );
     M_config.createParamMap( trainer_param_map );
 
-    ParamMap all_params;
-    all_params.add( system_param_map ).add( trainer_param_map );
-
 
     CmdLineParser cmd_parser( argc, argv );
 
-    // analyze command line
-    if ( ! cmd_parser.parse( all_params ) )
+    // analyze command line for system options.
+    cmd_parser.parse( system_param_map );
+    if ( help )
     {
         system_param_map.printHelp( std::cout );
         trainer_param_map.printHelp( std::cout );
@@ -234,10 +234,19 @@ TrainerAgent::doInit( const int argc,
     {
         ConfFileParser conf_parser( trainer_config_file.c_str() );
         conf_parser.parse( trainer_param_map );
-        // analyze command line again to overwiite the config file setting
-        cmd_parser.parse( all_params );
     }
 
+    // analyze command line for trainer options.
+    cmd_parser.parse( trainer_param_map );
+
+    if ( ! cmd_parser.invalidOptions().empty() )
+    {
+        std::cerr << "trainer: ***WARNING*** detected invalid options: ";
+        std::copy( cmd_parser.invalidOptions().begin(),
+                   cmd_parser.invalidOptions().end(),
+                   std::ostream_iterator< std::string >( std::cerr, " " ) );
+        std::cerr << std::endl;
+    }
     return true;
 }
 
